<?php
/** Kinyarwanda (Ikinyarwanda)
 *
 * @file
 * @ingroup Languages
 *
 * @author Nimusenge Priscille
 * @author Amir E. Aharoni
 */

$namespaceNames = [
	NS_MEDIA            => 'Itangazamakuru',
	NS_SPECIAL          => 'Ibidasanzwe',
	NS_TALK             => 'Ibiganiro',
	NS_USER             => 'Umukoresha',
	NS_USER_TALK        => 'Ibiganiro_by\'umukoresha',
	NS_PROJECT_TALK     => 'Ibiganiro_kuri_$1',
	NS_FILE             => 'Dosiye',
	NS_FILE_TALK        => 'Ibiganiro_kuri_dosiye',
	NS_MEDIAWIKI        => 'MediyaWiki',
	NS_MEDIAWIKI_TALK   => 'Ibiganiro_kuri_MediyaWiki',
	NS_TEMPLATE         => 'Inyandikorugero',
	NS_TEMPLATE_TALK    => 'Ibiganiro_ku_nyandikorugero',
	NS_HELP             => 'Ubufasha',
	NS_HELP_TALK        => 'Ibiganiro_ku_bufasha',
	NS_CATEGORY         => 'Ikiciro',
	NS_CATEGORY_TALK    => 'Ibiganiro_ku_byiciro',
];
